from setuptools import setup

setup(name='proto_distributions',
      version='0.1',
      description='Probability distributions',
      packages=['proto_distributions'],
      author = 'Emefiele-Konyeri Awinrin',
      author_email= 'awinrin4bless@gmail.com',
      zip_safe=False)
